#
# Makefile Template for Tessy
# Compiler: IAR ARM V5
# Debugger: LAUTERBACH TRACE32
# Template Version: 2
#

# Defines to be generated by Tessy:
#
# BUFFER_SIZE           :=
# COMPILER_DEFINES      :=
# COMPILER_DIALECT      :=
# COMPILER_INCLUDES     :=
# COMPILER_INSTALL_PATH :=
# CONFIG_HEADER_FILE    :=
# CPU                   :=
# ENDIANESS             :=
# EXEFILE_EXTENSION     :=
# INITOBJDIR            :=
# INITSRCDIR            :=
# LINKER_FILE           :=
# MODULE_PATH           :=
# MODULE_PATH_DOS       :=
# OBJFILE_EXTENSION     :=
# PROJECTROOT           :=
# TARGET_INSTALL_PATH   :=
# TESSY_BIN             :=
# TESSY_SYS             :=
# TESTOBJECT            :=
# TIMER_FILE            :=
# USER_LINK_OPTIONS     :=

#####################################################################
#BEGIN_DEFINES
#####################################################################

#
# Special macros for includes and defines
#
TS_DEF_SEPARATOR :=-D
define TS_DEFINE
$(subst ;, $(TS_DEF_SEPARATOR) ,$(1))
endef

TS_INC_SEPARATOR :=-I
define TS_INCLUDE
$(subst ;, $(TS_INC_SEPARATOR) ,$(1))
endef

TS_INCLUDES_FILE := includes
define TS_CREATE_INCLUDES_FILE
$(file >$(TS_INCLUDES_FILE)$(1).txt)
endef
define TS_ADD_TO_INCLUDES_FILE
$(foreach var,$(2),$(file >>$(TS_INCLUDES_FILE)$(1).txt,$(var)))
endef

ifneq ($(CONFIG_HEADER_FILE),)
CONFIG_HEADER_FILE := --dlib --dlib_config "$(CONFIG_HEADER_FILE)"
TS_LIB_TYPE := dlib
else
TS_LIB_TYPE := clib
endif

TESSY_SYS_DOS      := $(shell ts_pathname -s '$(TESSY_SYS)')
IAR_HOME         := $(shell ts_pathname -s '$(COMPILER_INSTALL_PATH)')
MODULE_PATH_DOS    := $(shell ts_pathname -s '$(MODULE_PATH_DOS)')

TS_NAME          := TS_TRACE32
IDE_NAME         := trace32
COMPANY_NAME     := iar
PROCESSOR_NAME   := arm_v5

all	 : master slave
master : $(MODULE_PATH)/ts_$(TESTOBJECT)_m.exe
slave  : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(EXEFILE_EXTENSION)

ifeq ("little","$(ENDIANESS)")
  TS_BYTEORDER := TS_HOST_BYTEORDER
  TS_BYTEORDER_OPTION := --endian=little
endif
ifeq ("big","$(ENDIANESS)")
  TS_BYTEORDER := TS_NET_BYTEORDER
  TS_BYTEORDER_OPTION := --endian=big
endif
ifndef TS_BYTEORDER
  $(error Attribute 'Endianess' has invalid value '$(ENDIANESS)', only 'little' and 'big' are allowed.)
endif

#
# MASTER & COMM Makefiles
# (you should not need to modify these settings)
#
M_COMM_MAKE		:=	$(TESSY_SYS)/make/master_$(IDE_NAME)_gnu_i386.mk
S_COMM_MAKE		:=	$(TESSY_SYS)/src/comm/comm_$(IDE_NAME)_$(COMPANY_NAME)_$(PROCESSOR_NAME).mk


#
# SLAVE
# (You may change these settings to use your own compiler/linker options)
#
S_COMP_OPTIONS := --cpu=$(CPU) $(COMPILER_DIALECT) --debug --no_cse --no_unroll --no_inline \
                  --no_code_motion --no_tbaa --no_clustering --no_scheduling $(TS_BYTEORDER_OPTION) \
                  -e --fpu=VFPv4_SP $(CONFIG_HEADER_FILE) --silent --cpu_mode thumb -On \
                  -D TESSY -D TS_SLAVE -D TS_ARM -D $(TS_NAME) -D TS_HAVE_FLOAT32 \
                  -D TS_HAVE_FLOAT64 -D TS_HAVE_INT64 -D TS_AVOID_COMM_RETURN
S_LINK_OPTIONS := --config "$(LINKER_FILE)" --semihosting --silent \
                  --entry $(or $(PROGRAM_START),__iar_program_start)
S_INCLUDES     := -I $(IAR_HOME)\INC\ -I $(IAR_HOME)\inc\$(TS_LIB_TYPE)\ -I $(IAR_HOME)\lib\$(TS_LIB_TYPE)\ \
                  -I $(TESSY_SYS_DOS)\include\tessy\comm\ -I $(MODULE_PATH_DOS)\

S_CC           := $(IAR_HOME)\bin\iccarm.exe
S_LINK         := $(IAR_HOME)\bin\ilinkarm.exe
S_STUB_OBJECT  := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs$(OBJFILE_EXTENSION)
S_UC_OBJECT    := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr$(OBJFILE_EXTENSION)

#####################################################################
#END_DEFINES
#####################################################################

#####################################################################
#BEGIN_SOURCE
#####################################################################

#
# Template rules
#
$(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER)$(OBJFILE_EXTENSION): $(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER).c
	$(call TS_CREATE_INCLUDES_FILE,$$(SOURCENUMBER))
	$(call TS_ADD_TO_INCLUDES_FILE,$$(SOURCENUMBER),$(S_INCLUDES)$(call TS_INCLUDE,$(USER_INCLUDES$$(SOURCENUMBER))))
	$(S_CC) -o $@ -f $(TS_INCLUDES_FILE)$$(SOURCENUMBER).txt $(S_COMP_OPTIONS) \
		$(call TS_DEFINE,$(USER_DEFINES$$(SOURCENUMBER))$(S_COM_OPTIONS)) \
		$(USER_COMP_OPTIONS$$(SOURCENUMBER)) "$<"


#####################################################################
#END_SOURCE
#####################################################################

#####################################################################
#BEGIN_TARGETS
#####################################################################

#
# COMPILE USERCODE / STUBS
#
$(S_UC_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr.c
	$(S_CC) -o $@ $(S_INCLUDES) $(S_COMP_OPTIONS) $<

$(S_STUB_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs.c
	$(S_CC) -o $@ $(S_INCLUDES) $(S_COMP_OPTIONS) $<

#
# COMPILE/LINK MASTER
#

include $(M_COMM_MAKE)


#
# COMPILE SLAVE COMMUNICATION MODULES

include $(S_COMM_MAKE)


#
# COMPILE/LINK SLAVE
#
$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.c
	@echo *
	@echo ***** Compiling Slave *****
	$(S_CC) -o $@ $(S_INCLUDES) $(S_COMP_OPTIONS) $<

#
# Handle Board Files
#
ifeq ("true","$(USE_BOARD_FILES)")
ifeq ("","$(INITOBJDIR)")
$(error Attribute 'Use Board Files' is set to true but 'InitObjDir' is empty.)
endif
INITOBJDIR := $(shell ts_pathname -s '$(INITOBJDIR)')
ifeq ("","$(INITSRCDIR)")
$(info Attribute 'InitSrcDir' is empty. Using objects for linking only.)
START_OBJS := $(wildcard $(INITOBJDIR)/*$(OBJFILE_EXTENSION))
else
INITSRCDIR := $(shell ts_pathname -s '$(INITSRCDIR)')
START_OBJS := $(patsubst $(INITSRCDIR)/%.c,$(INITOBJDIR)/%$(OBJFILE_EXTENSION),$(wildcard $(INITSRCDIR)/*.c)) \
              $(patsubst $(INITSRCDIR)/%.s,$(INITOBJDIR)/%$(OBJFILE_EXTENSION),$(wildcard $(INITSRCDIR)/*.s))

$(INITOBJDIR)/%$(OBJFILE_EXTENSION) : $(INITSRCDIR)/%.c
	$(S_CC) -o "$@" $(S_INCLUDES) -I$(INITSRCDIR) $(S_COMP_OPTIONS) "$<"

$(INITOBJDIR)/%$(OBJFILE_EXTENSION) : $(INITSRCDIR)/%.s
	$(S_CC) -o "$@" $(S_INCLUDES) $(S_COMP_OPTIONS) "$<"
endif
ifeq ("","$(START_OBJS)")
$(warning Attribute 'Use Board Files' is set to true but no objects were found.)
endif
endif

#
# Objects to be delete after the build process.
#
TS_INTERMEDIATE_OBJS := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) \
                        $(S_OBJECTS) $(S_SRC_OBJECTS) $(S_UC_OBJECT) $(S_STUB_OBJECT)
.INTERMEDIATE: $(TS_INTERMEDIATE_OBJS)

$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(EXEFILE_EXTENSION) : $(START_OBJS) $(TS_INTERMEDIATE_OBJS)
	@echo *
	@echo ***** Linking Slave *****
	$(S_LINK) $(START_OBJS) $(TS_INTERMEDIATE_OBJS) $(USER_LINK_OPTIONS) -o "$@" $(S_LINK_OPTIONS)

#####################################################################
#END_TARGETS
#####################################################################

